@@ -18,6 +18,7 @@
 
 #include "k7zip.h"
 #include "karchive_p.h"
+#include "loggingcategory.h"
 
 #include <QtCore/QDebug>
 #include <QtCore/QDir>
@@ -397,19 +398,19 @@ public:
     QVector<quint64> unpackSizes;
 };
 
-class K7Zip::K7ZipPrivate
+class Q_DECL_HIDDEN K7Zip::K7ZipPrivate
 {
 public:
     K7ZipPrivate(K7Zip *parent)
         : q(parent)
         , packPos(0)
         , numPackStreams(0)
-        , buffer(0)
+        , buffer(nullptr)
         , pos(0)
         , end(0)
         , headerSize(0)
         , countSize(0)
-        , m_currentFile(0)
+        , m_currentFile(nullptr)
     {
     }
 
@@ -483,7 +484,7 @@ public:
         digests.clear();
         isAnti.clear();
 
-        buffer = 0;
+        buffer = nullptr;
         pos = 0;
         end = 0;
         headerSize = 0;
@@ -563,7 +564,7 @@ int K7Zip::K7ZipPrivate::readByte()
 quint32 K7Zip::K7ZipPrivate::readUInt32()
 {
     if (!buffer || (quint64)(pos + 4) > end) {
-        qDebug() << "error size";
+        qCDebug(KArchiveLog) << "error size";
         return 0;
     }
 
@@ -575,7 +576,7 @@ quint32 K7Zip::K7ZipPrivate::readUInt32()
 quint64 K7Zip::K7ZipPrivate::readUInt64()
 {
     if (!buffer || (quint64)(pos + 8) > end) {
-        qDebug() << "error size";
+        qCDebug(KArchiveLog) << "error size";
         return 0;
     }
 
@@ -621,7 +622,7 @@ QString K7Zip::K7ZipPrivate::readString()
             }
         }
         if (i == rem) {
-            qDebug() << "read string error";
+            qCDebug(KArchiveLog) << "read string error";
             return QString();
         }
         rem = i;
@@ -629,7 +630,7 @@ QString K7Zip::K7ZipPrivate::readString()
 
     int len = (int)(rem / 2);
     if (len < 0 || (size_t)len * 2 != rem) {
-        qDebug() << "read string unsupported";
+        qCDebug(KArchiveLog) << "read string unsupported";
         return QString();
     }
 
@@ -725,7 +726,7 @@ void K7Zip::K7ZipPrivate::readHashDigests(int numItems,
 Folder *K7Zip::K7ZipPrivate::folderItem()
 {
     if (!buffer) {
-        return 0;
+        return nullptr;
     }
 
     Folder *folder = new Folder;
@@ -746,9 +747,9 @@ Folder *K7Zip::K7ZipPrivate::folderItem()
         unsigned char coderInfo = readByte();
         int codecIdSize = (coderInfo & 0xF);
         if (codecIdSize > 8) {
-            qDebug() << "unsupported codec id size";
+            qCDebug(KArchiveLog) << "unsupported codec id size";
             delete folder;
-            return 0;
+            return nullptr;
         }
         Folder::FolderInfo *info = new Folder::FolderInfo();
         std::unique_ptr<unsigned char[]> codecID(new unsigned char[codecIdSize]);
@@ -780,10 +781,10 @@ Folder *K7Zip::K7ZipPrivate::folderItem()
         }
 
         if ((coderInfo & 0x80) != 0) {
-            qDebug() << "unsupported";
+            qCDebug(KArchiveLog) << "unsupported";
             delete info;
             delete folder;
-            return 0;
+            return nullptr;
         }
 
         numInStreamsTotal += info->numInStreams;
@@ -812,7 +813,7 @@ Folder *K7Zip::K7ZipPrivate::folderItem()
             }
             if (folder->packedStreams.size() != 1) {
                 delete folder;
-                return 0;
+                return nullptr;
             }
         }
     }
@@ -831,7 +832,7 @@ bool K7Zip::K7ZipPrivate::readUInt64DefVector(int numFiles, QVector<quint64> &va
     if (external != 0) {
         int dataIndex = readNumber();
         if (dataIndex < 0 /*|| dataIndex >= dataVector->Size()*/) {
-            qDebug() << "wrong data index";
+            qCDebug(KArchiveLog) << "wrong data index";
             return false;
         }
 
@@ -862,7 +863,7 @@ bool K7Zip::K7ZipPrivate::readPackInfo()
     packCRCs.clear();
 
     if (!findAttribute(kSize)) {
-        qDebug() << "kSize not found";
+        qCDebug(KArchiveLog) << "kSize not found";
         return false;
     }
 
@@ -899,7 +900,7 @@ bool K7Zip::K7ZipPrivate::readUnpackInfo()
     }
 
     if (!findAttribute(kFolder)) {
-        qDebug() << "kFolder not found";
+        qCDebug(KArchiveLog) << "kFolder not found";
         return false;
     }
 
@@ -917,18 +918,18 @@ bool K7Zip::K7ZipPrivate::readUnpackInfo()
     case 1: {
         int dataIndex = readNumber();
         if (dataIndex < 0 /*|| dataIndex >= dataVector->Size()*/) {
-            qDebug() << "wrong data index";
+            qCDebug(KArchiveLog) << "wrong data index";
         }
         // TODO : go to the new index
         break;
     }
     default:
-        qDebug() << "external error";
+        qCDebug(KArchiveLog) << "external error";
         return false;
     }
 
     if (!findAttribute(kCodersUnpackSize)) {
-        qDebug() << "kCodersUnpackSize not found";
+        qCDebug(KArchiveLog) << "kCodersUnpackSize not found";
         return false;
     }
 
@@ -1133,7 +1134,7 @@ bool K7Zip::K7ZipPrivate::readMainStreamsInfo()
     for (;;) {
         type = readByte();
         if (type > ((quint32)1 << 30)) {
-            qDebug() << "type error";
+            qCDebug(KArchiveLog) << "type error";
             return false;
         }
         switch (type) {
@@ -1141,32 +1142,32 @@ bool K7Zip::K7ZipPrivate::readMainStreamsInfo()
             return true;
         case kPackInfo: {
             if (!readPackInfo()) {
-                qDebug() << "error during read pack information";
+                qCDebug(KArchiveLog) << "error during read pack information";
                 return false;
             }
             break;
         }
         case kUnpackInfo: {
             if (!readUnpackInfo()) {
-                qDebug() << "error during read pack information";
+                qCDebug(KArchiveLog) << "error during read pack information";
                 return false;
             }
             break;
         }
         case kSubStreamsInfo: {
             if (!readSubStreamsInfo()) {
-                qDebug() << "error during read substreams information";
+                qCDebug(KArchiveLog) << "error during read substreams information";
                 return false;
             }
             break;
         }
         default:
-            qDebug() << "Wrong type";
+            qCDebug(KArchiveLog) << "Wrong type";
             return false;
         }
     }
 
-    qDebug() << "should not reach";
+    qCDebug(KArchiveLog) << "should not reach";
     return false;
 }
 
@@ -1488,7 +1489,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
         quint64 unpackSize64 = folder->getUnpackSize();;
         size_t unpackSize = (size_t)unpackSize64;
         if (unpackSize != unpackSize64) {
-            qDebug() << "unsupported";
+            qCDebug(KArchiveLog) << "unsupported";
             return inflatedData;
         }
 
@@ -1544,7 +1545,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
             dev->seek(startPos);
             quint64 n = dev->read(encodedBuffer.get(), size);
             if (n != (quint64)size) {
-                qDebug() << "Failed read next size, should read " << size << ", read " << n;
+                qCDebug(KArchiveLog) << "Failed read next size, should read " << size << ", read " << n;
                 return inflatedData;
             }
             QByteArray deflatedData(encodedBuffer.get(), size);
@@ -1557,7 +1558,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
         QVector<QByteArray> inflatedDatas;
         QByteArray deflatedData;
         for (int j = 0; j < seqInStreams.size(); ++j) {
-            Folder::FolderInfo *coder = 0;
+            Folder::FolderInfo *coder = nullptr;
             if ((quint32)j != mainCoderIndex) {
                 coder = folder->folderInfos[coderIndexes[j]];
             } else {
@@ -1566,13 +1567,13 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
 
             deflatedData = datas[seqInStreams[j]];
 
-            KFilterBase *filter = 0;
+            KFilterBase *filter = nullptr;
 
             switch (coder->methodID) {
             case k_LZMA:
                 filter = KCompressionDevice::filterForCompressionType(KCompressionDevice::Xz);
                 if (!filter) {
-                    qDebug() << "filter not found";
+                    qCDebug(KArchiveLog) << "filter not found";
                     return QByteArray();
                 }
                 static_cast<KXzFilter *>(filter)->init(QIODevice::ReadOnly, KXzFilter::LZMA, coder->properties);
@@ -1580,7 +1581,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
             case k_LZMA2:
                 filter = KCompressionDevice::filterForCompressionType(KCompressionDevice::Xz);
                 if (!filter) {
-                    qDebug() << "filter not found";
+                    qCDebug(KArchiveLog) << "filter not found";
                     return QByteArray();
                 }
                 static_cast<KXzFilter *>(filter)->init(QIODevice::ReadOnly, KXzFilter::LZMA2, coder->properties);
@@ -1605,7 +1606,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
             case k_BCJ:
                 filter = KCompressionDevice::filterForCompressionType(KCompressionDevice::Xz);
                 if (!filter) {
-                    qDebug() << "filter not found";
+                    qCDebug(KArchiveLog) << "filter not found";
                     return QByteArray();
                 }
                 static_cast<KXzFilter *>(filter)->init(QIODevice::ReadOnly, KXzFilter::BCJ, coder->properties);
@@ -1619,7 +1620,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
             case k_BZip2:
                 filter = KCompressionDevice::filterForCompressionType(KCompressionDevice::BZip2);
                 if (!filter) {
-                    qDebug() << "filter not found";
+                    qCDebug(KArchiveLog) << "filter not found";
                     return QByteArray();
                 }
                 filter->init(QIODevice::ReadOnly);
@@ -1646,7 +1647,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
                 filter->setOutBuffer(outBuffer.data(), outBuffer.size());
                 result = filter->uncompress();
                 if (result == KFilterBase::Error) {
-                    qDebug() << " decode error";
+                    qCDebug(KArchiveLog) << " decode error";
                     filter->terminate();
                     delete filter;
                     return QByteArray();
@@ -1657,13 +1658,13 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
                 inflatedDataTmp.append(outBuffer.data(), uncompressedBytes);
 
                 if (result == KFilterBase::End) {
-                    //qDebug() << "Finished unpacking";
+                    //qCDebug(KArchiveLog) << "Finished unpacking";
                     break; // Finished.
                 }
             }
 
             if (result != KFilterBase::End && !filter->inBufferEmpty()) {
-                qDebug() << "decode failed result" << result;
+                qCDebug(KArchiveLog) << "decode failed result" << result;
                 filter->terminate();
                 delete filter;
                 return QByteArray();
@@ -1685,7 +1686,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
         if (folder->unpackCRCDefined) {
             quint32 crc = crc32(0, (Bytef *)(inflated.data()), unpackSize);
             if (crc != folder->unpackCRC) {
-                qDebug() << "wrong crc";
+                qCDebug(KArchiveLog) << "wrong crc";
                 return QByteArray();
             }
         }
@@ -2090,7 +2091,7 @@ QByteArray K7Zip::K7ZipPrivate::encodeStream(QVector<quint64> &packSizes, QVecto
 
         const int ret = flt.write(header);
         if (ret != header.size()) {
-            qDebug() << "write error write " << ret << "expected" << header.size();
+            qCDebug(KArchiveLog) << "write error write " << ret << "expected" << header.size();
             return encodedData;
         }
 
@@ -2303,6 +2304,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     QIODevice *dev = device();
 
     if (!dev) {
+        setErrorString(tr("Could not get underlying device"));
         return false;
     }
 
@@ -2310,13 +2312,13 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     // check signature
     qint64 n = dev->read(header, 32);
     if (n != 32) {
-        qDebug() << "read header failed";
+        setErrorString(tr("Read header failed"));
         return false;
     }
 
     for (int i = 0; i < 6; ++i) {
         if ((unsigned char)header[i] != k7zip_signature[i]) {
-            qDebug() << "check signature failed";
+            setErrorString(tr("Check signature failed"));
             return false;
         }
     }
@@ -2326,7 +2328,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     int minor = header[7];
 
     /*if (major > 0 || minor > 2) {
-        qDebug() << "wrong archive version";
+        qCDebug(KArchiveLog) << "wrong archive version";
         return false;
     }*/
 
@@ -2339,7 +2341,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     quint32 crc = crc32(0, (Bytef *)(header + 0xC), 20);
 
     if (crc != startHeaderCRC) {
-        qDebug() << "bad crc";
+        setErrorString(tr("Bad CRC"));
         return false;
     }
 
@@ -2348,10 +2350,12 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     }
 
     if (nextHeaderSize > (quint64)0xFFFFFFFF) {
+        setErrorString(tr("Next header size is too big"));
         return false;
     }
 
     if ((qint64)nextHeaderOffset < 0) {
+        setErrorString(tr("Next header size is less than zero"));
         return false;
     }
 
@@ -2362,7 +2366,9 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
     n = dev->read(inBuffer.data(), inBuffer.size());
     if (n != (qint64)nextHeaderSize) {
-        qDebug() << "Failed read next header size, should read " << nextHeaderSize << ", read " << n;
+        setErrorString(
+              tr("Failed read next header size; should read %1, read %2")
+              .arg(nextHeaderSize).arg(n));
         return false;
     }
     d->buffer = inBuffer.data();
@@ -2374,7 +2380,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     crc = crc32(0, (Bytef *)(d->buffer), (quint32)nextHeaderSize);
 
     if (crc != nextHeaderCRC) {
-        qDebug() << "bad next header crc";
+        setErrorString(tr("Bad next header CRC"));
         return false;
     }
 
@@ -2382,7 +2388,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     QByteArray decodedData;
     if (type != kHeader) {
         if (type != kEncodedHeader) {
-            qDebug() << "error in header";
+            setErrorString(tr("Error in header"));
             return false;
         }
 
@@ -2392,7 +2398,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
         if (external != 0) {
             int dataIndex = (int)d->readNumber();
             if (dataIndex < 0) {
-                //qDebug() << "dataIndex error";
+                //qCDebug(KArchiveLog) << "dataIndex error";
             }
             d->buffer = decodedData.constData();
             d->pos = 0;
@@ -2401,7 +2407,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
         type = d->readByte();
         if (type != kHeader) {
-            qDebug() << "error type should be kHeader";
+            setErrorString(tr("Wrong header type"));
             return false;
         }
     }
@@ -2411,19 +2417,19 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
     if (type == kArchiveProperties) {
         // TODO : implement this part
-        qDebug() << "not implemented";
+        setErrorString(tr("Not implemented"));
         return false;
     }
 
     if (type == kAdditionalStreamsInfo) {
         // TODO : implement this part
-        qDebug() << "not implemented";
+        setErrorString(tr("Not implemented"));
         return false;
     }
 
     if (type == kMainStreamsInfo) {
         if (!d->readMainStreamsInfo()) {
-            qDebug() << "error during read main streams information";
+            setErrorString(tr("Error while reading main streams information"));
             return false;
         }
         type = d->readByte();
@@ -2441,7 +2447,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
     }
 
     if (type != kFilesInfo) {
-        qDebug() << "read header error";
+        setErrorString(tr("Error while reading header"));
         return false;
     }
 
@@ -2491,19 +2497,17 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
                 break;
             case kCTime:
                 if (!d->readUInt64DefVector(numFiles, d->cTimes, d->cTimesDefined)) {
-                    qDebug() << "error read CTime";
                     return false;
                 }
                 break;
             case kATime:
                 if (!d->readUInt64DefVector(numFiles, d->aTimes, d->aTimesDefined)) {
-                    qDebug() << "error read ATime";
                     return false;
                 }
                 break;
             case kMTime:
                 if (!d->readUInt64DefVector(numFiles, d->mTimes, d->mTimesDefined)) {
-                    qDebug() << "error read MTime";
+                    setErrorString(tr("Error reading modification time"));
                     return false;
                 }
                 break;
@@ -2512,7 +2516,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
                 if (external != 0) {
                     int dataIndex = d->readNumber();
                     if (dataIndex < 0 /*|| dataIndex >= dataVector->Size()*/) {
-                        qDebug() << "wrong data index";
+                        qCDebug(KArchiveLog) << "wrong data index";
                     }
 
                     // TODO : go to the new index
@@ -2532,7 +2536,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
                 if (external != 0) {
                     int dataIndex = d->readNumber();
                     if (dataIndex < 0) {
-                        qDebug() << "wrong data index";
+                        qCDebug(KArchiveLog) << "wrong data index";
                     }
 
                     // TODO : go to the new index
@@ -2549,14 +2553,14 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
             }
             case kStartPos:
                 if (!d->readUInt64DefVector(numFiles, d->startPositions, d->startPositionsDefined)) {
-                    qDebug() << "error read MTime";
+                    setErrorString(tr("Error reading MTime"));
                     return false;
                 }
                 break;
             case kDummy: {
                 for (quint64 i = 0; i < size; i++) {
                     if (d->readByte() != 0) {
-                        qDebug() << "invalid";
+                        setErrorString(tr("Invalid"));
                         return false;
                     }
                 }
@@ -2579,7 +2583,11 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
         bool checkRecordsSize = (major > 0 ||
                                  minor > 2);
         if (checkRecordsSize && d->pos - ppp != size) {
-            qDebug() << "error read size failed checkRecordsSize:" << checkRecordsSize << "d->pos - ppp" << d->pos - ppp << "size" << size;
+            setErrorString(
+                tr(
+                    "Read size failed "
+                    "(checkRecordsSize: %1, d->pos - ppp: %2, size: %3)")
+                .arg(checkRecordsSize).arg(d->pos - ppp).arg(size));
             return false;
         }
     }
@@ -2666,14 +2674,14 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
         if (d->mTimesDefined[i]) {
             mTime = KArchivePrivate::time_tToDateTime(toTimeT(d->mTimes[i]));
         } else {
-            mTime = KArchivePrivate::time_tToDateTime(time(NULL));
+            mTime = KArchivePrivate::time_tToDateTime(time(nullptr));
         }
 
         if (fileInfo->isDir) {
             QString path = QDir::cleanPath(fileInfo->path);
             const KArchiveEntry *ent = rootDir()->entry(path);
             if (ent && ent->isDirectory()) {
-                e = 0;
+                e = nullptr;
             } else {
                 e = new KArchiveDirectory(this, entryName, access, mTime, rootDir()->user(), rootDir()->group(), QString()/*symlink*/);
             }
@@ -2682,7 +2690,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
                 e = new K7ZipFileEntry(this, entryName, access, mTime, rootDir()->user(), rootDir()->group(), QString()/*symlink*/, pos, fileInfo->size, d->outData);
             } else {
                 QString target = QFile::decodeName(d->outData.mid(pos, fileInfo->size));
-                e = new K7ZipFileEntry(this, entryName, access, mTime, rootDir()->user(), rootDir()->group(), target, 0, 0, 0);
+                e = new K7ZipFileEntry(this, entryName, access, mTime, rootDir()->user(), rootDir()->group(), target, 0, 0, nullptr);
             }
         }
 
@@ -2702,8 +2710,9 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
 bool K7Zip::closeArchive()
 {
+    // Unnecessary check (already checked by KArchive::close())
     if (!isOpen()) {
-        //qWarning() << "You must open the file before close it\n";
+        //qCWarning(KArchiveLog) << "You must open the file before close it\n";
         return false;
     }
 
@@ -2766,7 +2775,7 @@ bool K7Zip::closeArchive()
 
         const int ret = flt.write(d->outData);
         if (ret != d->outData.size()) {
-            qDebug() << "write error";
+            setErrorString(tr("Write error"));
             return false;
         }
 
@@ -2795,6 +2804,8 @@ bool K7Zip::closeArchive()
         encodedStream = d->encodeStream(packSizes, folders);
 
         if (folders.isEmpty()) {
+            // FIXME Not sure why this is an error. Come up with a better message
+            setErrorString(tr("Failed while encoding header"));
             return false;
         }
 
@@ -2831,7 +2842,7 @@ bool K7Zip::doFinishWriting(qint64 size)
 {
 
     d->m_currentFile->setSize(size);
-    d->m_currentFile = 0L;
+    d->m_currentFile = nullptr;
 
     return true;
 }
@@ -2839,6 +2850,7 @@ bool K7Zip::doFinishWriting(qint64 size)
 bool K7Zip::writeData(const char *data, qint64 size)
 {
     if (!d->m_currentFile) {
+        setErrorString(tr("No file currently selected"));
         return false;
     }
 
@@ -2857,12 +2869,14 @@ bool K7Zip::doPrepareWriting(const QString &name, const QString &user,
                              const QDateTime & /*atime*/, const QDateTime &mtime, const QDateTime & /*ctime*/)
 {
     if (!isOpen()) {
-        //qWarning() << "You must open the tar file before writing to it\n";
+        setErrorString(tr("Application error: 7-Zip file must be open before being written into"));
+        qCWarning(KArchiveLog) << "doPrepareWriting failed: !isOpen()";
         return false;
     }
 
     if (!(mode() & QIODevice::WriteOnly)) {
-        //qWarning() << "You must open the tar file for writing\n";
+        setErrorString(tr("Application error: attempted to write into non-writable 7-Zip file"));
+        qCWarning(KArchiveLog) << "doPrepareWriting failed: !(mode() & QIODevice::WriteOnly)";
         return false;
     }
 
@@ -2898,12 +2912,13 @@ bool K7Zip::doWriteDir(const QString &name, const QString &user,
                        const QDateTime & /*atime*/, const QDateTime &mtime, const QDateTime & /*ctime*/)
 {
     if (!isOpen()) {
-        //qWarning() << "You must open the tar file before writing to it\n";
+        setErrorString(tr("Application error: 7-Zip file must be open before being written into"));
+        qCWarning(KArchiveLog) << "doWriteDir failed: !isOpen()";
         return false;
     }
 
     if (!(mode() & QIODevice::WriteOnly)) {
-        //qWarning() << "You must open the tar file for writing\n";
+        //qCWarning(KArchiveLog) << "You must open the tar file for writing\n";
         return false;
     }
 
@@ -2934,12 +2949,14 @@ bool K7Zip::doWriteSymLink(const QString &name, const QString &target,
                            mode_t perm, const QDateTime & /*atime*/, const QDateTime &mtime, const QDateTime & /*ctime*/)
 {
     if (!isOpen()) {
-        //qWarning() << "You must open the tar file before writing to it\n";
+        setErrorString(tr("Application error: 7-Zip file must be open before being written into"));
+        qCWarning(KArchiveLog) << "doWriteSymLink failed: !isOpen()";
         return false;
     }
 
     if (!(mode() & QIODevice::WriteOnly)) {
-        //qWarning() << "You must open the tar file for writing\n";
+        setErrorString(tr("Application error: attempted to write into non-writable 7-Zip file"));
+        qCWarning(KArchiveLog) << "doWriteSymLink failed: !(mode() & QIODevice::WriteOnly)";
         return false;
     }
 
@@ -2955,7 +2972,7 @@ bool K7Zip::doWriteSymLink(const QString &name, const QString &target,
     }
     QByteArray encodedTarget = QFile::encodeName(target);
 
-    K7ZipFileEntry *e = new K7ZipFileEntry(this, fileName, perm, mtime, user, group, target, 0, 0, 0);
+    K7ZipFileEntry *e = new K7ZipFileEntry(this, fileName, perm, mtime, user, group, target, 0, 0, nullptr);
     d->outData.append(encodedTarget);
 
     parentDir->addEntry(e);
